﻿using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Delay;

namespace ListViewColumnWidthAutoUpdate
{
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();

            // Create a list for People objects
            var people = new Collection<Person>();

            // Add two simple People objects
            var joe = new Person("Joe");
            joe.Details.Add(new Detail("Job", "Pilot"));
            joe.Details.Add(new Detail("Hobby", "Music"));
            people.Add(joe);
            var jane = new Person("Jane");
            jane.Details.Add(new Detail("Job", "President of the Board"));
            jane.Details.Add(new Detail("Hobby", "Underwater basket weaving"));
            people.Add(jane);

            // Display the People collection/data
            PeopleBox.ItemsSource = people;
        }

        // Handler for the ListView's TargetUpdated event
        private void ListViewTargetUpdated(object sender, DataTransferEventArgs e)
        {
            // Get a reference to the ListView's GridView...
            var listView = sender as ListView;
            if (null != listView)
            {
                var gridView = listView.View as GridView;
                if (null != gridView)
                {
                    // ... and update its column widths
                    ListViewBehaviors.UpdateColumnWidths(gridView);
                }
            }
        }

        // Handler for Button's Click event
        private void AddDetail(object sender, RoutedEventArgs e)
        {
            var person = PeopleBox.SelectedItem as Person;
            if (null != person)
            {
                person.Details.Add(new Detail("New Detail", "This detail has a very long value"));
            }
        }
    }

    // Simple object representing a person with details
    public class Person
    {
        public string Name { get; private set; }
        public ObservableCollection<Detail> Details { get; private set; }
        public Person(string name)
        {
            Name = name;
            Details = new ObservableCollection<Detail>();
        }
        public override string ToString()
        {
            return Name;
        }
    }

    // Simple object representing details for a person
    public class Detail
    {
        public string Name { get; private set; }
        public string Value { get; private set; }
        public Detail(string name, string value)
        {
            Name = name;
            Value = value;
        }
    }
}
